import React, { useState, useEffect } from 'react';
import Actions from "@/Components/Buttons/Actions";
import Header from "@/Components/Header";
import PagTitle from "@/Components/Title/PagTitle";
import { Link, router } from '@inertiajs/react';
import Input from '@/Components/FormComponents/Input';
import Accordion from './Components/Accordion';
import toast, { Toaster } from 'react-hot-toast';
import New from './Components/New';
import NotFound from '@/Components/NotFound';
import Import from './Components/Import';
import Export from './Components/Export';
import ResultSearch from '@/Components/ResultSearch';

export default function Leads({ leads, totalLeads, queryParams = null }) {
    queryParams = queryParams || {};

    // Estado para controlar modal New
    const [isModalOpen, setIsModalOpen] = useState(false);
    const handleModalNewContact = () => { setIsModalOpen(true) };
    const handleCloseModal = () => { setIsModalOpen(false) };

    // Estado para controlar modal importar
    const [isModalImportOpen, setIsModalImportOpen] = useState(false);
    const handleModalImport = () => { setIsModalImportOpen(true) };
    const handleCloseModalImport = () => { setIsModalImportOpen(false) };

    // Estado para controlar modal export
    const [isModalExportOpen, setIsModalExportOpen] = useState(false);
    const handleModalExport = () => { setIsModalExportOpen(true) };
    const handleCloseModalExport = () => { setIsModalExportOpen(false) };

    // Estado para controlar accordion
    const [openIndex, setOpenIndex] = useState(null);
    const handleToggle = (index) => { setOpenIndex(prevIndex => (prevIndex === index ? null : index)) };

    // Menu de ações
    const items = [
        { name: 'Adicionar Contato', icon: 'bi bi-plus-lg', link: null, button: true, onPress: handleModalNewContact },
        { name: 'Exportar Contatos', icon: 'bi bi-download', link: null, button: true, onPress: handleModalExport },
        { name: 'Importar Contatos', icon: 'bi bi-upload', link: null, button: true, onPress: handleModalImport },
    ];

    const [searchTerm, setSearchTerm] = useState(queryParams.name || '');

    const searchFieldChanged = (value) => {
        setSearchTerm(value);
        const updatedParams = { ...queryParams, name: value || undefined };
        router.get(route("leads"), updatedParams, { preserveState: true });
    };

    // Lógica de requisições reutilizável
    const handleRequest = (postMethod, routeUrl, successMessage, openModal = null) => {
        postMethod(routeUrl, {
            onSuccess: () => {
                if (openModal) openModal();
                toast.success(successMessage);

                handleCloseModal();
            },
            onError: (errors) => {
                toast.error(errors?.error || 'Ocorreu um erro inesperado.');
            },
        });
    };

    useEffect(() => {
        const delayDebounce = setTimeout(() => {
            searchFieldChanged(searchTerm);
        }, 500);

        return () => clearTimeout(delayDebounce);
    }, [searchTerm]);

    return (
        <>
            <div className="container mx-auto px-4">
                <Toaster />
                <Header />

                <div className="flex justify-between items-center mt-4 mb-8">
                    <div className="flex justify-start items-center">
                        <Link href={route('settings')} className="me-3">
                            <i className="bi bi-arrow-left-circle-fill text-text-primary hover:text-text-white text-3xl"></i>
                        </Link>
                        <PagTitle title="Contatos" subtitle="Aqui você pode gerenciar os seus contatos." />
                    </div>

                    <Actions items={items} />
                </div>

                <div className="lg:max-w-5xl mx-auto mt-10 lg:p-4">

                    <div className='md:flex md:justify-between items-center mb-4'>
                        <Input
                            className="w-full md:w-80"
                            value={searchTerm}
                            placeholder="Nome, E-mail ou Telefone..."
                            onChange={(e) => setSearchTerm(e.target.value)}
                        />

                        <p className="text-text-primary text-[.8rem] mt-4 md:mt-0 text-end">
                            Exibindo <span className="font-extrabold">{leads.data.length}</span> de <span className="font-extrabold">{totalLeads}</span> contatos
                        </p>
                    </div>

                    {queryParams.name && <ResultSearch total={leads.data.length} />}

                    {leads.data.length > 0 ? (
                        leads.data.map((lead, index) => (
                            <Accordion
                                lead={lead}
                                index={index}
                                key={index}
                                openIndex={openIndex}
                                handleToggle={handleToggle}
                                handleRequest={handleRequest}
                            />
                        ))
                    ) : (<NotFound />)}
                </div>
            </div>

            <New isModalOpen={isModalOpen} handleCloseModal={handleCloseModal} />
            <Import isModalOpen={isModalImportOpen} handleCloseModal={handleCloseModalImport} />
            <Export isModalOpen={isModalExportOpen} handleCloseModal={handleCloseModalExport} />
        </>
    );
}
